@@ -4,7 +4,6 @@ import re
 import pandas as pd
 
 from mskit import rapid_kit
-from ._deeprt_constant import MOD
 
 
 def newrt_format_to_deeprt(rt_df: pd.DataFrame, pep_col='IntPep'):
@@ -95,3 +94,23 @@ def trans_sn_mod(modpep):
         return None
     modpep = modpep.strip('_')
     return modpep
+
+
+MOD = {
+    'C[Carbamidomethyl (C)]': 'C',
+    'M[Oxidation (M)]': '1',
+    'S[Phospho (S)]': '2',
+    'T[Phospho (T)]': '3',
+    'Y[Phospho (Y)]': '4',
+
+    'C[Carbamidomethyl]': 'C',
+    'M[Oxidation]': '1',
+    'S[Phospho]': '2',
+    'T[Phospho]': '3',
+    'Y[Phospho]': '4',
+
+    'M[16]': '1',
+    'S[80]': '2',
+    'T[80]': '3',
+    'Y[80]': '4',
+}
